pub enum SessionError {
Socket(UdpSocketError),
Packet(PacketError),
PayloadTooLarge {
payload_len: usize,
max_payload_len: usize,
},
FrameAlreadyQueued,
FrameNotReady {
next_frame_in_us: time_tp,
},
FeedbackTimeout {
waited_us: time_tp,
inflight_packets: count_tp,
},
WouldBlock {
next_send_in_us: time_tp,
inflight_packets: count_tp,
packet_window: count_tp,
},
UnexpectedPacketType(u8),
InvalidPacket(&'static str),
}Expand description
Errors that can occur while using the higher-level session wrapper APIs.
Variants
Socket(UdpSocketError)
UDP socket operation failed.
Packet(PacketError)
Packet view construction or parsing failed.
PayloadTooLarge
The app payload did not fit in the current Prague packet budget.
Fields
FrameAlreadyQueued
A video frame was queued while another one was still pending.
FrameNotReady
The next video frame slot has not opened yet.
FeedbackTimeout
A blocking helper timed out while waiting for feedback needed to make progress.
Fields
WouldBlock
The sender is pacing-limited or window-limited and cannot send yet.
Fields
UnexpectedPacketType(u8)
A packet of an unexpected type was received for the current session role.
InvalidPacket(&'static str)
A packet passed structural parsing but was invalid for the higher-level wrapper.